# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplugin.proto\x12\x05proto\x1a\x1cgoogle/protobuf/struct.proto\"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c\"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error\"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"0\n\x18PGetCapabilitiesResponse\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x01(\x04\"\x07\n\x05\x45mpty\"&\n\x11IsRunningResponse\x12\x11\n\tisRunning\x18\x01 \x01(\x08\";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"/\n\x10\x45mitInputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c\"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05\"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"D\n\x13SetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\"=\n\x14SetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"8\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x14GetRobotInfoResponse\x12&\n\x05robot\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"5\n\x11\x41ppRequestRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"&\n\x13\x41ppRequestV2Request\x12\x0f\n\x07request\x18\x01 \x01(\x0c\"&\n\x12\x41ppRequestResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c\"$\n\x11\x41ppPublishRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\"0\n\x13\x44ownloadFileRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x12\x41ppDownloadRequest\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"#\n\x13\x41ppDownloadResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\",\n\x10\x41ppUploadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\" \n\x11\x41ppUploadResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xb3\x01\n\x15GatewayRequestRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12:\n\x07headers\x18\x03 \x03(\x0b\x32).proto.GatewayRequestRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x16GatewayRequestResponse\x12\x12\n\nstatusCode\x18\x01 \x01(\x05\x12;\n\x07headers\x18\x02 \x03(\x0b\x32*.proto.GatewayRequestResponse.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x0bHttpRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x30\n\x07headers\x18\x03 \x03(\x0b\x32\x1f.proto.HttpRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x04 \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x0cHttpResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x31\n\x07headers\x18\x02 \x03(\x0b\x32 .proto.HttpResponse.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"9\n\x08NodeInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x03 \x01(\x0c\"7\n\x19GetPortConnectionsRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"<\n\x1aGetPortConnectionsResponse\x12\x1e\n\x05nodes\x18\x01 \x03(\x0b\x32\x0f.proto.NodeInfo2\xa9\x02\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse\x12@\n\x0fGetCapabilities\x12\x0c.proto.Empty\x1a\x1f.proto.PGetCapabilitiesResponse2\x9d\n\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitInput\x12\x17.proto.EmitInputRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12G\n\x0cSetVaultItem\x12\x1a.proto.SetVaultItemRequest\x1a\x1b.proto.SetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Empty\x12\x39\n\x0cGetRobotInfo\x12\x0c.proto.Empty\x1a\x1b.proto.GetRobotInfoResponse\x12\x41\n\nAppRequest\x12\x18.proto.AppRequestRequest\x1a\x19.proto.AppRequestResponse\x12\x45\n\x0c\x41ppRequestV2\x12\x1a.proto.AppRequestV2Request\x1a\x19.proto.AppRequestResponse\x12\x34\n\nAppPublish\x12\x18.proto.AppPublishRequest\x1a\x0c.proto.Empty\x12\x38\n\x0c\x44ownloadFile\x12\x1a.proto.DownloadFileRequest\x1a\x0c.proto.Empty\x12\x44\n\x0b\x41ppDownload\x12\x19.proto.AppDownloadRequest\x1a\x1a.proto.AppDownloadResponse\x12>\n\tAppUpload\x12\x17.proto.AppUploadRequest\x1a\x18.proto.AppUploadResponse\x12M\n\x0eGatewayRequest\x12\x1c.proto.GatewayRequestRequest\x1a\x1d.proto.GatewayRequestResponse\x12\x37\n\x0cProxyRequest\x12\x12.proto.HttpRequest\x1a\x13.proto.HttpResponse\x12Y\n\x12GetPortConnections\x12 .proto.GetPortConnectionsRequest\x1a!.proto.GetPortConnectionsResponse\x12\x33\n\tIsRunning\x12\x0c.proto.Empty\x1a\x18.proto.IsRunningResponseB$Z\"robomotion/robomotion-runner/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'plugin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\"robomotion/robomotion-runner/proto'
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPRESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ERROR']._serialized_start=53
  _globals['_ERROR']._serialized_end=103
  _globals['_INITREQUEST']._serialized_start=105
  _globals['_INITREQUEST']._serialized_end=154
  _globals['_ONCREATEREQUEST']._serialized_start=156
  _globals['_ONCREATEREQUEST']._serialized_end=203
  _globals['_ONCREATERESPONSE']._serialized_start=205
  _globals['_ONCREATERESPONSE']._serialized_end=252
  _globals['_ONMESSAGEREQUEST']._serialized_start=254
  _globals['_ONMESSAGEREQUEST']._serialized_end=305
  _globals['_ONMESSAGERESPONSE']._serialized_start=307
  _globals['_ONMESSAGERESPONSE']._serialized_end=375
  _globals['_ONCLOSEREQUEST']._serialized_start=377
  _globals['_ONCLOSEREQUEST']._serialized_end=407
  _globals['_ONCLOSERESPONSE']._serialized_start=409
  _globals['_ONCLOSERESPONSE']._serialized_end=455
  _globals['_PGETCAPABILITIESRESPONSE']._serialized_start=457
  _globals['_PGETCAPABILITIESRESPONSE']._serialized_end=505
  _globals['_EMPTY']._serialized_start=507
  _globals['_EMPTY']._serialized_end=514
  _globals['_ISRUNNINGRESPONSE']._serialized_start=516
  _globals['_ISRUNNINGRESPONSE']._serialized_end=554
  _globals['_DEBUGREQUEST']._serialized_start=556
  _globals['_DEBUGREQUEST']._serialized_end=615
  _globals['_EMITFLOWEVENTREQUEST']._serialized_start=617
  _globals['_EMITFLOWEVENTREQUEST']._serialized_end=667
  _globals['_EMITINPUTREQUEST']._serialized_start=669
  _globals['_EMITINPUTREQUEST']._serialized_end=716
  _globals['_EMITOUTPUTREQUEST']._serialized_start=718
  _globals['_EMITOUTPUTREQUEST']._serialized_end=781
  _globals['_EMITERRORREQUEST']._serialized_start=783
  _globals['_EMITERRORREQUEST']._serialized_end=846
  _globals['_GETVAULTITEMREQUEST']._serialized_start=848
  _globals['_GETVAULTITEMREQUEST']._serialized_end=902
  _globals['_GETVAULTITEMRESPONSE']._serialized_start=904
  _globals['_GETVAULTITEMRESPONSE']._serialized_end=965
  _globals['_SETVAULTITEMREQUEST']._serialized_start=967
  _globals['_SETVAULTITEMREQUEST']._serialized_end=1035
  _globals['_SETVAULTITEMRESPONSE']._serialized_start=1037
  _globals['_SETVAULTITEMRESPONSE']._serialized_end=1098
  _globals['_VARIABLE']._serialized_start=1100
  _globals['_VARIABLE']._serialized_end=1156
  _globals['_GETVARIABLEREQUEST']._serialized_start=1158
  _globals['_GETVARIABLEREQUEST']._serialized_end=1213
  _globals['_GETVARIABLERESPONSE']._serialized_start=1215
  _globals['_GETVARIABLERESPONSE']._serialized_end=1276
  _globals['_SETVARIABLEREQUEST']._serialized_start=1278
  _globals['_SETVARIABLEREQUEST']._serialized_end=1373
  _globals['_GETROBOTINFORESPONSE']._serialized_start=1375
  _globals['_GETROBOTINFORESPONSE']._serialized_end=1437
  _globals['_APPREQUESTREQUEST']._serialized_start=1439
  _globals['_APPREQUESTREQUEST']._serialized_end=1492
  _globals['_APPREQUESTV2REQUEST']._serialized_start=1494
  _globals['_APPREQUESTV2REQUEST']._serialized_end=1532
  _globals['_APPREQUESTRESPONSE']._serialized_start=1534
  _globals['_APPREQUESTRESPONSE']._serialized_end=1572
  _globals['_APPPUBLISHREQUEST']._serialized_start=1574
  _globals['_APPPUBLISHREQUEST']._serialized_end=1610
  _globals['_DOWNLOADFILEREQUEST']._serialized_start=1612
  _globals['_DOWNLOADFILEREQUEST']._serialized_end=1660
  _globals['_APPDOWNLOADREQUEST']._serialized_start=1662
  _globals['_APPDOWNLOADREQUEST']._serialized_end=1727
  _globals['_APPDOWNLOADRESPONSE']._serialized_start=1729
  _globals['_APPDOWNLOADRESPONSE']._serialized_end=1764
  _globals['_APPUPLOADREQUEST']._serialized_start=1766
  _globals['_APPUPLOADREQUEST']._serialized_end=1810
  _globals['_APPUPLOADRESPONSE']._serialized_start=1812
  _globals['_APPUPLOADRESPONSE']._serialized_end=1844
  _globals['_GATEWAYREQUESTREQUEST']._serialized_start=1847
  _globals['_GATEWAYREQUESTREQUEST']._serialized_end=2026
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_start=1980
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_end=2026
  _globals['_GATEWAYREQUESTRESPONSE']._serialized_start=2029
  _globals['_GATEWAYREQUESTRESPONSE']._serialized_end=2196
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_start=1980
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_end=2026
  _globals['_HTTPREQUEST']._serialized_start=2199
  _globals['_HTTPREQUEST']._serialized_end=2353
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_start=1980
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_end=2026
  _globals['_HTTPRESPONSE']._serialized_start=2356
  _globals['_HTTPRESPONSE']._serialized_end=2504
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_start=1980
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_end=2026
  _globals['_NODEINFO']._serialized_start=2506
  _globals['_NODEINFO']._serialized_end=2563
  _globals['_GETPORTCONNECTIONSREQUEST']._serialized_start=2565
  _globals['_GETPORTCONNECTIONSREQUEST']._serialized_end=2620
  _globals['_GETPORTCONNECTIONSRESPONSE']._serialized_start=2622
  _globals['_GETPORTCONNECTIONSRESPONSE']._serialized_end=2682
  _globals['_NODE']._serialized_start=2685
  _globals['_NODE']._serialized_end=2982
  _globals['_RUNTIMEHELPER']._serialized_start=2985
  _globals['_RUNTIMEHELPER']._serialized_end=4294
# @@protoc_insertion_point(module_scope)
