# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

import plugin_pb2 as plugin__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in plugin_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class NodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
                '/proto.Node/Init',
                request_serializer=plugin__pb2.InitRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.OnCreate = channel.unary_unary(
                '/proto.Node/OnCreate',
                request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
                response_deserializer=plugin__pb2.OnCreateResponse.FromString,
                _registered_method=True)
        self.OnMessage = channel.unary_unary(
                '/proto.Node/OnMessage',
                request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
                response_deserializer=plugin__pb2.OnMessageResponse.FromString,
                _registered_method=True)
        self.OnClose = channel.unary_unary(
                '/proto.Node/OnClose',
                request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
                response_deserializer=plugin__pb2.OnCloseResponse.FromString,
                _registered_method=True)
        self.GetCapabilities = channel.unary_unary(
                '/proto.Node/GetCapabilities',
                request_serializer=plugin__pb2.Empty.SerializeToString,
                response_deserializer=plugin__pb2.PGetCapabilitiesResponse.FromString,
                _registered_method=True)


class NodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnClose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCapabilities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Init': grpc.unary_unary_rpc_method_handler(
                    servicer.Init,
                    request_deserializer=plugin__pb2.InitRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'OnCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.OnCreate,
                    request_deserializer=plugin__pb2.OnCreateRequest.FromString,
                    response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
            ),
            'OnMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.OnMessage,
                    request_deserializer=plugin__pb2.OnMessageRequest.FromString,
                    response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
            ),
            'OnClose': grpc.unary_unary_rpc_method_handler(
                    servicer.OnClose,
                    request_deserializer=plugin__pb2.OnCloseRequest.FromString,
                    response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
            ),
            'GetCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCapabilities,
                    request_deserializer=plugin__pb2.Empty.FromString,
                    response_serializer=plugin__pb2.PGetCapabilitiesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'proto.Node', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('proto.Node', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Node(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.Node/Init',
            plugin__pb2.InitRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OnCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.Node/OnCreate',
            plugin__pb2.OnCreateRequest.SerializeToString,
            plugin__pb2.OnCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OnMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.Node/OnMessage',
            plugin__pb2.OnMessageRequest.SerializeToString,
            plugin__pb2.OnMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OnClose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.Node/OnClose',
            plugin__pb2.OnCloseRequest.SerializeToString,
            plugin__pb2.OnCloseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.Node/GetCapabilities',
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.PGetCapabilitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class RuntimeHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Close = channel.unary_unary(
                '/proto.RuntimeHelper/Close',
                request_serializer=plugin__pb2.Empty.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.Debug = channel.unary_unary(
                '/proto.RuntimeHelper/Debug',
                request_serializer=plugin__pb2.DebugRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.EmitFlowEvent = channel.unary_unary(
                '/proto.RuntimeHelper/EmitFlowEvent',
                request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.EmitInput = channel.unary_unary(
                '/proto.RuntimeHelper/EmitInput',
                request_serializer=plugin__pb2.EmitInputRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.EmitOutput = channel.unary_unary(
                '/proto.RuntimeHelper/EmitOutput',
                request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.EmitError = channel.unary_unary(
                '/proto.RuntimeHelper/EmitError',
                request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.GetVaultItem = channel.unary_unary(
                '/proto.RuntimeHelper/GetVaultItem',
                request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
                response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
                _registered_method=True)
        self.SetVaultItem = channel.unary_unary(
                '/proto.RuntimeHelper/SetVaultItem',
                request_serializer=plugin__pb2.SetVaultItemRequest.SerializeToString,
                response_deserializer=plugin__pb2.SetVaultItemResponse.FromString,
                _registered_method=True)
        self.GetVariable = channel.unary_unary(
                '/proto.RuntimeHelper/GetVariable',
                request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
                response_deserializer=plugin__pb2.GetVariableResponse.FromString,
                _registered_method=True)
        self.SetVariable = channel.unary_unary(
                '/proto.RuntimeHelper/SetVariable',
                request_serializer=plugin__pb2.SetVariableRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.GetRobotInfo = channel.unary_unary(
                '/proto.RuntimeHelper/GetRobotInfo',
                request_serializer=plugin__pb2.Empty.SerializeToString,
                response_deserializer=plugin__pb2.GetRobotInfoResponse.FromString,
                _registered_method=True)
        self.AppRequest = channel.unary_unary(
                '/proto.RuntimeHelper/AppRequest',
                request_serializer=plugin__pb2.AppRequestRequest.SerializeToString,
                response_deserializer=plugin__pb2.AppRequestResponse.FromString,
                _registered_method=True)
        self.AppRequestV2 = channel.unary_unary(
                '/proto.RuntimeHelper/AppRequestV2',
                request_serializer=plugin__pb2.AppRequestV2Request.SerializeToString,
                response_deserializer=plugin__pb2.AppRequestResponse.FromString,
                _registered_method=True)
        self.AppPublish = channel.unary_unary(
                '/proto.RuntimeHelper/AppPublish',
                request_serializer=plugin__pb2.AppPublishRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.DownloadFile = channel.unary_unary(
                '/proto.RuntimeHelper/DownloadFile',
                request_serializer=plugin__pb2.DownloadFileRequest.SerializeToString,
                response_deserializer=plugin__pb2.Empty.FromString,
                _registered_method=True)
        self.AppDownload = channel.unary_unary(
                '/proto.RuntimeHelper/AppDownload',
                request_serializer=plugin__pb2.AppDownloadRequest.SerializeToString,
                response_deserializer=plugin__pb2.AppDownloadResponse.FromString,
                _registered_method=True)
        self.AppUpload = channel.unary_unary(
                '/proto.RuntimeHelper/AppUpload',
                request_serializer=plugin__pb2.AppUploadRequest.SerializeToString,
                response_deserializer=plugin__pb2.AppUploadResponse.FromString,
                _registered_method=True)
        self.GatewayRequest = channel.unary_unary(
                '/proto.RuntimeHelper/GatewayRequest',
                request_serializer=plugin__pb2.GatewayRequestRequest.SerializeToString,
                response_deserializer=plugin__pb2.GatewayRequestResponse.FromString,
                _registered_method=True)
        self.ProxyRequest = channel.unary_unary(
                '/proto.RuntimeHelper/ProxyRequest',
                request_serializer=plugin__pb2.HttpRequest.SerializeToString,
                response_deserializer=plugin__pb2.HttpResponse.FromString,
                _registered_method=True)
        self.GetPortConnections = channel.unary_unary(
                '/proto.RuntimeHelper/GetPortConnections',
                request_serializer=plugin__pb2.GetPortConnectionsRequest.SerializeToString,
                response_deserializer=plugin__pb2.GetPortConnectionsResponse.FromString,
                _registered_method=True)
        self.IsRunning = channel.unary_unary(
                '/proto.RuntimeHelper/IsRunning',
                request_serializer=plugin__pb2.Empty.SerializeToString,
                response_deserializer=plugin__pb2.IsRunningResponse.FromString,
                _registered_method=True)


class RuntimeHelperServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Debug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitFlowEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitInput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRobotInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppRequestV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppPublish(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppDownload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GatewayRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProxyRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPortConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsRunning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RuntimeHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Close': grpc.unary_unary_rpc_method_handler(
                    servicer.Close,
                    request_deserializer=plugin__pb2.Empty.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'Debug': grpc.unary_unary_rpc_method_handler(
                    servicer.Debug,
                    request_deserializer=plugin__pb2.DebugRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'EmitFlowEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.EmitFlowEvent,
                    request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'EmitInput': grpc.unary_unary_rpc_method_handler(
                    servicer.EmitInput,
                    request_deserializer=plugin__pb2.EmitInputRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'EmitOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.EmitOutput,
                    request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'EmitError': grpc.unary_unary_rpc_method_handler(
                    servicer.EmitError,
                    request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'GetVaultItem': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVaultItem,
                    request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
                    response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
            ),
            'SetVaultItem': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVaultItem,
                    request_deserializer=plugin__pb2.SetVaultItemRequest.FromString,
                    response_serializer=plugin__pb2.SetVaultItemResponse.SerializeToString,
            ),
            'GetVariable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVariable,
                    request_deserializer=plugin__pb2.GetVariableRequest.FromString,
                    response_serializer=plugin__pb2.GetVariableResponse.SerializeToString,
            ),
            'SetVariable': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVariable,
                    request_deserializer=plugin__pb2.SetVariableRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'GetRobotInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRobotInfo,
                    request_deserializer=plugin__pb2.Empty.FromString,
                    response_serializer=plugin__pb2.GetRobotInfoResponse.SerializeToString,
            ),
            'AppRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.AppRequest,
                    request_deserializer=plugin__pb2.AppRequestRequest.FromString,
                    response_serializer=plugin__pb2.AppRequestResponse.SerializeToString,
            ),
            'AppRequestV2': grpc.unary_unary_rpc_method_handler(
                    servicer.AppRequestV2,
                    request_deserializer=plugin__pb2.AppRequestV2Request.FromString,
                    response_serializer=plugin__pb2.AppRequestResponse.SerializeToString,
            ),
            'AppPublish': grpc.unary_unary_rpc_method_handler(
                    servicer.AppPublish,
                    request_deserializer=plugin__pb2.AppPublishRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'DownloadFile': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadFile,
                    request_deserializer=plugin__pb2.DownloadFileRequest.FromString,
                    response_serializer=plugin__pb2.Empty.SerializeToString,
            ),
            'AppDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.AppDownload,
                    request_deserializer=plugin__pb2.AppDownloadRequest.FromString,
                    response_serializer=plugin__pb2.AppDownloadResponse.SerializeToString,
            ),
            'AppUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.AppUpload,
                    request_deserializer=plugin__pb2.AppUploadRequest.FromString,
                    response_serializer=plugin__pb2.AppUploadResponse.SerializeToString,
            ),
            'GatewayRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GatewayRequest,
                    request_deserializer=plugin__pb2.GatewayRequestRequest.FromString,
                    response_serializer=plugin__pb2.GatewayRequestResponse.SerializeToString,
            ),
            'ProxyRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ProxyRequest,
                    request_deserializer=plugin__pb2.HttpRequest.FromString,
                    response_serializer=plugin__pb2.HttpResponse.SerializeToString,
            ),
            'GetPortConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPortConnections,
                    request_deserializer=plugin__pb2.GetPortConnectionsRequest.FromString,
                    response_serializer=plugin__pb2.GetPortConnectionsResponse.SerializeToString,
            ),
            'IsRunning': grpc.unary_unary_rpc_method_handler(
                    servicer.IsRunning,
                    request_deserializer=plugin__pb2.Empty.FromString,
                    response_serializer=plugin__pb2.IsRunningResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'proto.RuntimeHelper', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('proto.RuntimeHelper', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RuntimeHelper(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/Close',
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Debug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/Debug',
            plugin__pb2.DebugRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EmitFlowEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/EmitFlowEvent',
            plugin__pb2.EmitFlowEventRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EmitInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/EmitInput',
            plugin__pb2.EmitInputRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EmitOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/EmitOutput',
            plugin__pb2.EmitOutputRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EmitError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/EmitError',
            plugin__pb2.EmitErrorRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetVaultItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/GetVaultItem',
            plugin__pb2.GetVaultItemRequest.SerializeToString,
            plugin__pb2.GetVaultItemResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetVaultItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/SetVaultItem',
            plugin__pb2.SetVaultItemRequest.SerializeToString,
            plugin__pb2.SetVaultItemResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetVariable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/GetVariable',
            plugin__pb2.GetVariableRequest.SerializeToString,
            plugin__pb2.GetVariableResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetVariable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/SetVariable',
            plugin__pb2.SetVariableRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRobotInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/GetRobotInfo',
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.GetRobotInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AppRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/AppRequest',
            plugin__pb2.AppRequestRequest.SerializeToString,
            plugin__pb2.AppRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AppRequestV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/AppRequestV2',
            plugin__pb2.AppRequestV2Request.SerializeToString,
            plugin__pb2.AppRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AppPublish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/AppPublish',
            plugin__pb2.AppPublishRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/DownloadFile',
            plugin__pb2.DownloadFileRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AppDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/AppDownload',
            plugin__pb2.AppDownloadRequest.SerializeToString,
            plugin__pb2.AppDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AppUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/AppUpload',
            plugin__pb2.AppUploadRequest.SerializeToString,
            plugin__pb2.AppUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GatewayRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/GatewayRequest',
            plugin__pb2.GatewayRequestRequest.SerializeToString,
            plugin__pb2.GatewayRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProxyRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/ProxyRequest',
            plugin__pb2.HttpRequest.SerializeToString,
            plugin__pb2.HttpResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPortConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/GetPortConnections',
            plugin__pb2.GetPortConnectionsRequest.SerializeToString,
            plugin__pb2.GetPortConnectionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsRunning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/proto.RuntimeHelper/IsRunning',
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.IsRunningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
