# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: runner.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'runner.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0crunner.proto\x12\x05proto\"\x06\n\x04Null\"\x82\x01\n\x11InitRunnerRequest\x12\x0e\n\x06\x61piUrl\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0crobot_server\x18\x03 \x01(\r\x12\x10\n\x08natsPort\x18\x04 \x01(\r\x12\x12\n\nrobot_name\x18\x05 \x01(\t\x12\x12\n\nsend_crash\x18\x06 \x01(\x08\"T\n\nRunRequest\x12\x0e\n\x06repoid\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\'\n\x11RobotNameResponse\x12\x12\n\nrobot_name\x18\x01 \x01(\t\"\x05\n\x03Nil\"\x1f\n\rAttachRequest\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\x0c\"\"\n\rDetachRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t2\xb5\x01\n\x06Runner\x12-\n\x04Init\x12\x18.proto.InitRunnerRequest\x1a\x0b.proto.Null\x12%\n\x03Run\x12\x11.proto.RunRequest\x1a\x0b.proto.Null\x12!\n\x05\x43lear\x12\x0b.proto.Null\x1a\x0b.proto.Null\x12\x32\n\tRobotName\x12\x0b.proto.Null\x1a\x18.proto.RobotNameResponse2\r\n\x0bRobotHelper2_\n\x05\x44\x65\x62ug\x12*\n\x06\x41ttach\x12\x14.proto.AttachRequest\x1a\n.proto.Nil\x12*\n\x06\x44\x65tach\x12\x14.proto.DetachRequest\x1a\n.proto.NilB*Z(robomotion/robomotion-runner/robot/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'runner_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(robomotion/robomotion-runner/robot/proto'
  _globals['_NULL']._serialized_start=23
  _globals['_NULL']._serialized_end=29
  _globals['_INITRUNNERREQUEST']._serialized_start=32
  _globals['_INITRUNNERREQUEST']._serialized_end=162
  _globals['_RUNREQUEST']._serialized_start=164
  _globals['_RUNREQUEST']._serialized_end=248
  _globals['_ROBOTNAMERESPONSE']._serialized_start=250
  _globals['_ROBOTNAMERESPONSE']._serialized_end=289
  _globals['_NIL']._serialized_start=291
  _globals['_NIL']._serialized_end=296
  _globals['_ATTACHREQUEST']._serialized_start=298
  _globals['_ATTACHREQUEST']._serialized_end=329
  _globals['_DETACHREQUEST']._serialized_start=331
  _globals['_DETACHREQUEST']._serialized_end=365
  _globals['_RUNNER']._serialized_start=368
  _globals['_RUNNER']._serialized_end=549
  _globals['_ROBOTHELPER']._serialized_start=551
  _globals['_ROBOTHELPER']._serialized_end=564
  _globals['_DEBUG']._serialized_start=566
  _globals['_DEBUG']._serialized_end=661
# @@protoc_insertion_point(module_scope)
